@@ -2,7 +2,7 @@ package App::Yath::Command::run;
 use strict;
 use warnings;
 
-our $VERSION = '1.000063';
+our $VERSION = '1.000064';
 
 use App::Yath::Options;
 
@@ -13,7 +13,6 @@ use Test2::Harness::IPC;
 
 use App::Yath::Util qw/find_pfile/;
 use Test2::Harness::Util qw/open_file/;
-use Test2::Harness::Util::JSON qw/encode_json decode_json/;
 use Test2::Harness::Util qw/mod2file open_file/;
 use Test2::Util::Table qw/table/;
 
@@ -49,6 +48,7 @@ sub terminate_queue {}
 sub write_settings_to {}
 sub setup_plugins {}
 sub teardown_plugins {}
+sub finalize_plugins {}
 
 sub monitor_preloads { 1 }
 sub job_count { 1 }
@@ -245,6 +245,72 @@ Can be specified multiple times
 
 =head2 COMMAND OPTIONS
 
+=head3 Cover Options
+
+=over 4
+
+=item --cover-dirs ARG
+
+=item --cover-dirs=ARG
+
+=item --cover-dir ARG
+
+=item --cover-dir=ARG
+
+=item --no-cover-dirs
+
+NO DESCRIPTION - FIX ME
+
+Can be specified multiple times
+
+
+=item --cover-exclude-private
+
+=item --no-cover-exclude-private
+
+
+
+
+=item --cover-files
+
+=item --no-cover-files
+
+Use Test2::Plugin::Cover to collect coverage data for what files are touched by what tests. Unlike Devel::Cover this has very little performance impact (About 4% difference)
+
+
+=item --cover-metrics
+
+=item --no-cover-metrics
+
+
+
+
+=item --cover-types ARG
+
+=item --cover-types=ARG
+
+=item --cover-type ARG
+
+=item --cover-type=ARG
+
+=item --no-cover-types
+
+NO DESCRIPTION - FIX ME
+
+Can be specified multiple times
+
+
+=item --cover-write
+
+=item --cover-write=coverage.json
+
+=item --no-cover-write
+
+Create a json file of all coverage data seen during the run (This implies --cover-files).
+
+
+=back
+
 =head3 Display Options
 
 =over 4
@@ -721,15 +787,6 @@ Specify the format for automatically-generated log files. Overridden by --log-fi
 Can also be set with the following environment variables: C<YATH_LOG_FILE_FORMAT>, C<TEST2_HARNESS_LOG_FORMAT>
 
 
-=item --write-coverage
-
-=item --write-coverage=coverage.json
-
-=item --no-write-coverage
-
-Create a json file of all coverage data seen during the run (This implies --cover-files).
-
-
 =back
 
 =head3 Notification Options
@@ -863,13 +920,6 @@ Use the specified module to generate messages for emails and/or slack.
 This will set the AUTHOR_TESTING environment to true
 
 
-=item --cover-files
-
-=item --no-cover-files
-
-Use Test2::Plugin::Cover to collect coverage data for what files are touched by what tests. Unlike Devel::Cover this has very little performance impact (About 4% difference)
-
-
 =item --dbi-profiling
 
 =item --no-dbi-profiling
