@@ -2,7 +2,7 @@ package App::Yath::Plugin;
 use strict;
 use warnings;
 
-our $VERSION = '1.000063';
+our $VERSION = '1.000064';
 
 use parent 'Test2::Harness::Plugin';
 
@@ -12,6 +12,8 @@ use parent 'Test2::Harness::Plugin';
 
 sub finish {}
 
+sub finalize {}
+
 1;
 
 __END__
@@ -121,6 +123,12 @@ C<< { pass => $bool } >>.
         ],
     }
 
+=item $plugin->finalize($settings)
+
+This is called as late as possible before exit. This is mainly useful for
+outputting messages such as "Extra log file written to ..." which are best put
+at the end of output.
+
 =back
 
 =head1 SOURCE
